@@ -13,7 +13,7 @@ use PerlMaple::Expression;
 use Carp qw(carp croak);
 use vars qw( $AUTOLOAD );
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 my $Started = 0;
 
 require XSLoader;
@@ -124,7 +124,7 @@ PerlMaple - Perl binding for Maplesoft's Maple mathematical package
 
 =head1 VERSION
 
-This document describes PerlMaple 0.06 released on May 2rd, 2006.
+This document describes PerlMaple 0.07 released on Nov 20, 2009.
 
 =head1 SYNOPSIS
 
@@ -330,7 +330,7 @@ The PrintError attribute can be used to force errors to generate warnings
 (using Carp::carp) in addition to returning error codes in the normal way. When
 set ``on'' (say, a true value), any method which results in an error
 occurring will cause the PerlMaple to effectively do a
-C<carp("PerlMaple error: ", $self->error, " when evaluating \"$exp\"";)>.
+C<< carp("PerlMaple error: ", $self->error, " when evaluating \"$exp\"";) >>.
 Any warnings from the Maple kernel will also be sent to stderr via carp
 if PrintError is on.
 
@@ -344,7 +344,7 @@ The RaiseError attribute can be used to force errors to raise exceptions
 rather than simply return error codes in the normal way. It is ``off''
 (say, a false value in Perl) by default. When set ``on'', any method
 which results in an error will cause the PerlMaple to effectively do a
-C<croak("PerlMaple error: ", $self->error, " when evaluating \"$exp\"";)>.
+C<< croak("PerlMaple error: ", $self->error, " when evaluating \"$exp\"";) >>.
 
 If you turn RaiseError on then you'd normally turn PrintError off.
 If PrintError is also on, then the PrintError is done first (naturally).
